@@ -1,16 +1,23 @@
 #' @export
 
 plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
-
+  
+  fit_args <- extract_arguments(output)
+  
+  # Give error if save is false
+  if(fit_args$save == FALSE){
+    stop("The plot cannot be obtained for this model fit as the posterior samples weren't stored. Rerun the model fit and set 'save = TRUE'.")
+  }
+  
   # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = FALSE,
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
   output <- res
-
+  
   # Specify default arguments for function
   default_args <- list(
     xlab = "Structures",
@@ -25,12 +32,12 @@ plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
     axis.title.y = element_text(size = 18, face = "bold"),
     panel.grid.major = element_blank()
   )
-
+  
   args <- set_defaults(default_args, ...)
   sorted_structure_prob <- as.data.frame(sort(output$structure_probabilities, decreasing = TRUE))
   colnames(sorted_structure_prob) <- "posterior_prob"
   if(as_BF){
-
+    
     BF1s <- sorted_structure_prob$posterior_prob[1] / sorted_structure_prob$posterior_prob # BF best structure vs. others
     data <- data.frame(structures = 1:length(BF1s), BayesFactor = BF1s)
     ggplot2::ggplot(data, aes(x = .data$structures, y = .data$BayesFactor, ...)) +
@@ -69,16 +76,23 @@ plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
 #'
 
 plot_complexity_probabilities.bgms <- function(output, ...) {
-
+  
+  fit_args <- extract_arguments(output)
+  
+  # Give error if save is false
+  if(fit_args$save == FALSE){
+    stop("The plot cannot be obtained for this model fit as the posterior samples weren't stored. Rerun the model fit and set 'save = TRUE'.")
+  }
+  
   # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = FALSE,
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
   output <- res
-
+  
   # Specify default arguments for function
   default_args <- list(
     xlab = "Complexity",
@@ -93,18 +107,18 @@ plot_complexity_probabilities.bgms <- function(output, ...) {
     axis.title.y = element_text(size = 18, face = "bold"),
     panel.grid.major = element_blank()
   )
-
+  
   args <- set_defaults(default_args, ...)
   complexity <- c()
   for(i in 1:length(output$sample_graph)){
     complexity[i] <- sum(as.numeric(unlist(strsplit(output$sample_graph[i], ""))))
   }
-
+  
   data_complexity <- data.frame(complexity = complexity, weights = output$graph_weights) |>
     dplyr::group_by(complexity) |>
     dplyr::summarise(complexity_weight = sum(.data$weights)) |>
     dplyr::mutate(complexity_weight = .data$complexity_weight/sum(.data$complexity_weight))
-
+  
   ggplot(data_complexity, aes(x = .data$complexity, y = .data$complexity_weight, ...)) +
     geom_point(size = 3) +
     ylab(args$ylab) +
@@ -117,7 +131,7 @@ plot_complexity_probabilities.bgms <- function(output, ...) {
           axis.title.x = args$axis.title.x,
           axis.title.y = args$axis.title.y,
           panel.grid.major = args$panel.grid.major
-
+          
     )
 }
 
@@ -125,16 +139,23 @@ plot_complexity_probabilities.bgms <- function(output, ...) {
 
 #' @export
 
-plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE, show = "all", donotplot = FALSE,...) {
-  # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = FALSE,
+plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE, show = "all", ...) {
+  
+  fit_args <- extract_arguments(output)
+  
+  if(!fit_args$edge_selection){
+    stop("The plot cannot be obtained for this model fit as no posterior edge inclusion probabilities were obtained. Rerun the model fit and set 'edge_selection = TRUE'.")
+  }
+  
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
+  
   output <- res
-
+  
   # Specify default arguments for function
   default_args <- list(
     colors = c("#36648b", "#990000", "#bfbfbf"),
@@ -147,18 +168,18 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
     edge.width = 3,
     label.cex = 1,
     legend.cex = .6
-
+    
   )
   args <- set_defaults(default_args, ...)
   graph <- output$inc_BF
   diag(graph) <- 1
-
+  
   # assign a color to each edge (inclusion - blue, exclusion - red, no conclusion - grey)
   graph_color <- graph
   graph_color <-  ifelse(graph < evidence_thresh & graph > 1/evidence_thresh,
                          graph_color <- args$colors[3], graph_color <- args$colors[1])
   graph_color[graph < (1/evidence_thresh)] <- args$colors[2]
-
+  
   if (show == "all") {
     if (!split) {
       graph[output$inc_probs <= 1] <- 1
@@ -177,9 +198,9 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
                                     ...
       )
     }
-
+    
     if (split) {
-
+      
       graph_inc <- graph_exc <- graph
       # plot included graph
       graph_inc[output$inc_probs >= .5] <- 1
@@ -243,31 +264,34 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
                                   ...
     )
   }
-  if(donotplot && split){
+  if (split == TRUE) {
     return(invisible(list(qgraph_plot1, qgraph_plot2)))
-  } else if(donotplot && !split){
-    return(invisible(qgraph_plot))
-  } else if(!donotplot && split){
-    return(plot(qgraph_plot1))
-    return(plot(qgraph_plot2))
   } else {
-    return(plot(qgraph_plot))
+    return(invisible(qgraph_plot))
   }
 }
 
 # ---------------------------------------------------------------------------------------------------------------
 #' @export
 
-plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = FALSE, donotplot = FALSE,...) {
-  # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = FALSE,
+plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = TRUE, ...) {
+  
+  fit_args <- extract_arguments(output)
+  
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
+  
   output <- res
-
+  
+  if(is.null(output$inc_probs)){
+    dashed <- FALSE
+    warning("The model was fitted without edge selection and no inclusion probabilities were obtained. Therefore, edges cannot be dashed according to their PIP.",
+            call. = FALSE)
+  }
   # Specify default arguments for function
   graph <- output$parameters
   default_args <- list(
@@ -281,12 +305,12 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
     legend.cex = .6
   )
   args <- set_defaults(default_args, ...)
-
+  
   # Exclude edges with a inclusion probability lower exc_prob
   inc_probs_m <- output$inc_probs
   graph[inc_probs_m < exc_prob] <- 0
   diag(graph) <- 1
-
+  
   # Plot
   if(dashed){
     graph_dashed <- ifelse(output$inc_BF < args$evidence_thres, "dashed", "solid")
@@ -303,29 +327,28 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
                                   legend = args$legend,
                                   label.cex = args$label.cex,
                                   legend.cex = args$legend.cex, ...)
-
-  }
-  if(donotplot){
-    return(invisible(qgraph_plot))
-  } else {
-    return(plot(qgraph_plot))
+    
   }
+  return(invisible(qgraph_plot))
 }
 
 # -------------------------------------------------
 
 #' @export
 
-plot_structure.bgms <- function(output, donotplot = FALSE,...) {
-  # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = FALSE,
+plot_structure.bgms <- function(output, ...) {
+  
+  fit_args <- extract_arguments(output)
+  
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
+  
   output <- res
-
+  
   # Specify default arguments for function
   default_args <- list(
     layout_avg = qgraph::averageLayout(output$parameters*output$structure),
@@ -349,11 +372,7 @@ plot_structure.bgms <- function(output, donotplot = FALSE,...) {
                                 legend = args$legend,
                                 label.cex = args$label.cex,
                                 legend.cex = args$legend.cex, ...)
-  if(donotplot){
-    return(invisible(qgraph_plot))
-  } else {
-    return(plot(qgraph_plot))
-  }
+  return(invisible(qgraph_plot))
 }
 
 # ---------------------------------------------------------------------------------------------------------------
@@ -361,22 +380,21 @@ plot_structure.bgms <- function(output, donotplot = FALSE,...) {
 #' @export
 
 plot_parameterHDI.bgms <- function(output, ...) {
-
-
-  if(!output$save){
+  
+  fit_args <- extract_arguments(output)
+  
+  if(!fit_args$save){
     stop("Samples of the posterior distribution required. When estimating the model with bgm, set \"save = TRUE\".")
   }
-
-
-  # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = FALSE,
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
+  
   output <- res
-
+  
   # Specify default arguments for function
   def_args <- list(
     theme_ = theme_bw(),
@@ -395,24 +413,24 @@ plot_parameterHDI.bgms <- function(output, ...) {
       plot.title = element_text(size = 18, face = "bold")
     )
   )
-
+  
   args <- set_defaults(def_args, ...)
   hdi_intervals <- as.data.frame(apply(output$samples_posterior, MARGIN = 2, FUN = hdi))
   posterior_medians <- apply(output$samples_posterior, MARGIN = 2, FUN = median)
-
+  
   names <- colnames(output$parameters)
   names_bycol <- matrix(rep(names, each = ncol(output$parameters)), ncol = ncol(output$parameters))
   names_byrow <- matrix(rep(names, each = ncol(output$parameters)), ncol = ncol(output$parameters), byrow = T)
   names_comb <- matrix(paste0(names_byrow, "-", names_bycol), ncol = ncol(output$parameters))
   index <- names_comb[upper.tri(names_comb)]
-
+  
   posterior <- cbind(data.frame(posterior_medians, row.names = NULL),
                      data.frame(t(hdi_intervals), row.names = NULL), index)
   colnames(posterior) <- c("posterior_medians", "lower", "upper", "names")
   posterior <- posterior[order(posterior$posterior_medians, decreasing = FALSE),]
   posterior$names <- factor(posterior$names, levels = posterior$names)
-
-
+  
+  
   ggplot2::ggplot(data = posterior, aes(x = .data$names, y = .data$posterior_medians, ymin = .data$lower,
                                         ymax = .data$upper, ...)) +
     args$geom_pointrange +
@@ -422,7 +440,7 @@ plot_parameterHDI.bgms <- function(output, ...) {
     xlab(args$xlab) +
     args$geom_hline +
     args$theme
-
+  
 }
 
 
@@ -431,20 +449,22 @@ plot_parameterHDI.bgms <- function(output, ...) {
 #' @export
 
 plot_centrality.bgms <- function(output, ...){
-
-  if(!output$save){
+  
+  fit_args <- extract_arguments(output)
+  
+  if(!fit_args$save){
     stop("Samples of the posterior distribution required. When estimating the model with bgm, set \"save = TRUE\".")
   }
-
-  # Extract the results from bgms
-  res <- bgm_extract.package_bgms(fit = output, save = output$save, centrality = TRUE,
+  
+  res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = TRUE,
                                   type = NULL, not_cont = NULL, data = NULL,
-                                  edge_prior = output$edge_prior,
-                                  inclusion_probability  = output$inclusion_probability,
-                                  beta_bernoulli_alpha = output$beta_bernoulli_alpha,
-                                  beta_bernoulli_beta = output$beta_bernoulli_beta)
+                                  edge_prior = fit_args$edge_prior,
+                                  inclusion_probability  = fit_args$inclusion_probability,
+                                  beta_bernoulli_alpha = fit_args$beta_bernoulli_alpha,
+                                  beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
+  
   output <- res
-
+  
   # Specify default arguments for function
   default_args <- list(
     theme_ = theme_minimal(),
@@ -464,13 +484,13 @@ plot_centrality.bgms <- function(output, ...){
       panel.grid.major = element_blank()
     )
   )
-
+  
   args <- set_defaults(default_args, ...)
   cent_samples <- output$centrality
   p <- ncol(output$parameters)
   rownames(cent_samples) <- NULL
   # Creating summary statistics
-
+  
   centrality_means <- colMeans(cent_samples)
   centrality_hdi <- apply(cent_samples, MARGIN = 2, FUN = hdi, allowSplit = FALSE)
   if(is.null(colnames(output$parameters))) {
@@ -482,7 +502,7 @@ plot_centrality.bgms <- function(output, ...){
                                    mean = centrality_means,
                                    lower = centrality_hdi[1, ],
                                    upper = centrality_hdi[2, ])
-
+  
   centrality_summary |>
     dplyr::arrange(mean) |>
     dplyr::mutate(node = factor(.data$node, levels = .data$node)) |>
